package de.cnam.jemina.ui.components;

import com.vaadin.data.util.BeanItem;
import com.vaadin.ui.Embedded;
import com.vaadin.ui.Label;
import com.vaadin.ui.Table;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.objects.Buch;
import de.cnam.jemina.objects.CD;
import de.cnam.jemina.objects.Video;
import de.cnam.jemina.objects.Zeitschrift;
import de.cnam.jemina.resource.ImgThemeResource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Zur Darstellung von Artikel
 *
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class ArticleIconColumnGenerator implements Table.ColumnGenerator {

    // Logging:
    private final Logger log = LoggerFactory.getLogger(ArticleIconColumnGenerator.class);
    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(ArticleIconColumnGenerator.class);

    @Override
    public Object generateCell(Table source, Object itemId, Object columnId) {
        Object res = null;

        Object bean = ((BeanItem) source.getItem(itemId)).getBean();

        if (bean instanceof Buch) {
            res = new Embedded(locale.localize("book"), new ImgThemeResource("Books"));
        }
        if (bean instanceof Zeitschrift) {
            res = new Embedded(locale.localize("paper"), new ImgThemeResource("ClosedBook"));
        }
        if (bean instanceof CD) {
            res = new Embedded(locale.localize("cd"), new ImgThemeResource("CD"));
        }
        if (bean instanceof Video) {
            res = new Embedded(locale.localize("video"), new ImgThemeResource("VideoCamera"));
        }

        if (res == null) {
            log.warn("Unbekannter Artikel-Typ: {}", bean.getClass().getName());
            res = new Label(bean.getClass().getName());
        }


        return res;
    }
}
