package de.cnam.jemina.ui.controlls.impl;

import com.vaadin.data.util.BeanItemContainer;
import com.vaadin.ui.Component;
import de.cnam.jemina.entrypoint.IJeminaApplication;
import de.cnam.jemina.extern.auth.IUser;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.objects.Artikel;
import de.cnam.jemina.ui.components.DisplayArticle;
import de.cnam.jemina.ui.controlls.IControll;
import de.cnam.jemina.ui.controlls.listener.ArticleControllListener;
import de.cnam.jemina.ui.controlls.listener.SearchListener;
import de.cnam.jemina.ui.views.impl.DisplaySearchResultsView;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Modul "DisplaySearchResultsControll"
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class DisplaySearchResultsControll implements IControll {

    public static final String MODUL_NAME = "DisplaySearchResultsControll";
    public static final String MODUL_ICON = null;

    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(DisplaySearchResultsControll.class);
    
    // Logging:
    private final Logger log = LoggerFactory.getLogger(DisplaySearchResultsControll.class);
    
    // View (UI)
    private DisplaySearchResultsView view;
    
    // Applikation:
    private final IJeminaApplication app;

    /**
     * Konstruktor
     * @param app Die Anwendungsklasse zur Kommunikation
     */
    public DisplaySearchResultsControll(IJeminaApplication app) {
        this.app = app;
    }


    @Override
    public String getName() {
        return MODUL_NAME;
    }

    @Override
    public String getIconName() {
        return MODUL_ICON;
    }

    @Override
    public String getCaption() {
        return locale.localize(MODUL_NAME);
    }

    @Override
    public Component open(Object obj, Map additionalParameters) {
        if (obj == null) {
            return null;
        }
        
        //
        view = new DisplaySearchResultsView(this);
        view.setSearchWord(obj.toString());
        view.setSuchListener(new SearchListener(app));
        
        // Artikel-Liste laden
        try {
            List<Artikel> searchRes = app.getPersistentObj().selectArticle(obj.toString());
            BeanItemContainer container = new BeanItemContainer(Artikel.class, searchRes);            
            view.setResultList(container);
        } catch (SQLException | IllegalArgumentException ex) {
            log.error("Konnte Suche nach '{}' nicht durchfuehren: {}", obj, ex.getLocalizedMessage());
        }
        
        // Berechtigungen setzen:
        if (app.getUser() != null) {
            if (app.getUser().getRole() == IUser.ROLLE.MITARBEITER) {
                view.setRights(true, true, true, true, true);
            }
            
            if (app.getUser().getRole() == IUser.ROLLE.STUDENT) {
                view.setRights(false, false, false, false, true);
            }
            
            // Listener setzen:
            DisplayArticle.IArticleControllerListener listener = new ArticleControllListener(app);
            view.setActionListener(listener);
            
        } else {
            // Kein Recht, da nicht angemeldet
            view.setRights(false, false, false, false, false);
        }
        
        return view;
    }
    
    /**
     * Da in der &Uuml;bersicht nicht alle Details des Artikels geladen wurden,
     * m&uuml;ssen diese bei Bedarf nachgeladen werden
     * @param a
     * @return 
     */
    public Artikel loadArtikelDetails(Artikel a) {
        try {
            if (log.isDebugEnabled()) {
                log.debug("Lade Details zu Artikel {}", a.getId());
            }
            Artikel artikel = app.getPersistentObj().loadArtikelDetails(a.getId());
            return artikel;
        } catch (Exception ex) {
            log.error("Es gab einen Fehler beim Laden des Artikels {}: {}", a, ex.getLocalizedMessage());
            return a;
        }
    }
}
