package de.cnam.jemina.ui.controlls.impl;

import com.vaadin.data.util.BeanItemContainer;
import com.vaadin.ui.Component;
import de.cnam.jemina.entrypoint.IJeminaApplication;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.objects.Reservierung;
import de.cnam.jemina.ui.controlls.IControll;
import de.cnam.jemina.ui.views.impl.ListMyItemsView;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Modul "ListMyItems"
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class ListMyItemsControll implements IControll {

    public static final String MODUL_NAME = "ListMyItems";
    public static final String MODUL_ICON = "Books";

    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(ListMyItemsControll.class);
    
    // Logging:
    private final Logger log = LoggerFactory.getLogger(ListMyItemsControll.class);
    
    // View (UI)
    private ListMyItemsView view;
    
    // Applikation:
    private final IJeminaApplication app;

    /**
     * Konstruktor
     * @param app Die Anwendungsklasse zur Kommunikation
     */
    public ListMyItemsControll(IJeminaApplication app) {
        this.app = app;
    }


    @Override
    public String getName() {
        return MODUL_NAME;
    }

    @Override
    public String getIconName() {
        return MODUL_ICON;
    }

    @Override
    public String getCaption() {
        return locale.localize(MODUL_NAME);
    }

    @Override
    public Component open(Object obj, Map additionalParameters) {
        view = new ListMyItemsView();
        
        // Lade aus der Persistenzklasse
        try {
            List<Reservierung> reser = app.getPersistentObj().getReserveFromUser(app.getUser());
            view.setContainer(new BeanItemContainer(Reservierung.class, reser));
        } catch (SQLException | IllegalArgumentException ex) {
            log.error("Konnte die Reservierungsliste nicht abfragen", ex);
            app.showError(locale.localize("error"));
        }
        
        return view;
    }
}
