package de.cnam.jemina.ui.controlls.impl;

import com.vaadin.ui.Button;
import com.vaadin.ui.Button.ClickEvent;
import com.vaadin.ui.Component;
import de.cnam.jemina.entrypoint.IJeminaApplication;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.objects.Reservierung;
import de.cnam.jemina.ui.components.SearchComponent;
import de.cnam.jemina.ui.controlls.IControll;
import de.cnam.jemina.ui.views.impl.LoanView;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Modul "LoanControll"
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class LoanControll implements IControll {

    public static final String MODUL_NAME = "LoanControll";
    public static final String MODUL_ICON = "Cube";

    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(LoanControll.class);
    
    // Logging:
    private final Logger log = LoggerFactory.getLogger(LoanControll.class);
    
    // View (UI)
    private LoanView view;
    
    // Applikation:
    private final IJeminaApplication app;

    /**
     * Konstruktor
     * @param app Die Anwendungsklasse zur Kommunikation
     */
    public LoanControll(IJeminaApplication app) {
        this.app = app;
    }


    @Override
    public String getName() {
        return MODUL_NAME;
    }

    @Override
    public String getIconName() {
        return MODUL_ICON;
    }

    @Override
    public String getCaption() {
        return locale.localize(MODUL_NAME);
    }

    @Override
    public Component open(Object obj, Map additionalParameters) {
        view = new LoanView();
        
        // Wird nach der Eingabe einer Reservierungsnummer aufgerufen:
        view.setSuchListener(new SearchComponent.SuchListener() {
            @Override
            public void suche(String suchbegriff) {
                try {
                    Reservierung r = app.getPersistentObj().getReserve(suchbegriff);                    
                    if (r != null) {
                        List<Integer> eids = app.getPersistentObj().getExemplarIds(r.getArtikel(), false);
                        view.showReservierung(r, eids);
                    } else {
                        app.showInfo(locale.localize("notfound"));
                    }
                } catch (SQLException ex) {
                    log.error("Es gab ein Fehler beim Abruf der Reservierung", ex);
                    app.showError(locale.localize("error"));
                }
            }
        });
        
        // Wird nach der Eingabe einer Exemplar-Nr. aufgerufen
        view.addAusleiheListener(new Button.ClickListener() {
            @Override
            public void buttonClick(ClickEvent event) {
                Integer eid = (Integer) view.getExemplarId();
                if (eid != null) {
                    try {
                        app.getPersistentObj().loan(view.getReservierung(), eid);
                        
                        // Reload
                        app.openModul(MODUL_NAME, null, null);
                        
                    } catch (Exception ex) {
                        log.error("Es gab einen Fehler beim Ausleihen", ex);
                    }
                }
            }
        });
        
        return view;
    }
}
