package de.cnam.jemina.ui.views.utils;

import com.vaadin.ui.Table;
import de.cnam.jemina.i18n.LocalizationManager;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Util-Klasse f&uuml;r Views
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public abstract class ViewUtils {
    
    // Logging:
    private static final Logger log = LoggerFactory.getLogger(ViewUtils.class);
    
    /**
     * &Uuml;bersetzt die Spalten&uuml;berschriften der Tabelle.
     * Als Key wird der Spaltenname verwendet
     * @param table Tabelle deren &Uuml;berschriften &uuml;bersetzt werden sollen
     * @param locale Inzanz des {@link LocalizationManager}
     */
    public static void translateTableHeader(Table table, LocalizationManager locale) {
        if (table == null || locale == null) {
            log.warn("NULL Parameter");
            return;
        }
        
        String[] headers = table.getColumnHeaders();
        for (String head : headers) {
            table.setColumnHeader(head, locale.localize(head));
        }
        
        // Logging
        if (log.isDebugEnabled()) {
            log.debug("{} Spaltenueberschriften uebersetzt", headers.length);
        }
    }

}
